@@ -9,7 +9,8 @@ from pypsql_api.config.types import Session
 from pypsql_api.wire.actions_types import Names
 from pypsql_api.context import Context
 from pypsql_api.wire.back import SSLNo, AuthenticationCleartextPassword, ReadyForQuery, AuthenticationOk, \
-    EmptyQueryResponse, DataFrameRowDescription, DataFrameDataRows, CommandComplete, SSLYes, ErrorResponse
+    EmptyQueryResponse, DataFrameRowDescription, DataFrameDataRows, CommandComplete, SSLYes, ErrorResponse, \
+    ParameterStatus
 from pypsql_api.wire.bytes import ReadingIO, WritingIO
 from pypsql_api.wire.errors.core import log_exception, NoData
 from pypsql_api.wire.front import SSLRequest, StartupMessage, Message, PasswordMessage
@@ -165,6 +166,11 @@ def write_ready_for_query(context: Context):
 
 def write_auth_ok(context: Context):
     AuthenticationOk().write(context.output)
+
+    # write out the parameters for the server
+    for k,v in context.parameters.items():
+        ParameterStatus(name=k, value=v).write(context.output)
+
     context.output.flush()
 
     return context, Names.READY_FOR_QUERY
@@ -173,7 +179,7 @@ def write_auth_ok(context: Context):
 def read_receive_command(context: Context):
     m, t = Message.read(context.input)
 
-    print(f">>read_receive_command msg {m}, {t}")
+    logging.info(f">>read_receive_command msg {m}, {t}")
     if not (m and t):
         return context, None
 
@@ -183,15 +189,15 @@ def read_receive_command(context: Context):
 def read_receive_extended_command(context: Context):
     m, t = Message.read(context.input)
 
-    print(f">>read_receive_extended_command msg {m}, {t}")
+    logging.info(f">>read_receive_extended_command msg {m}, {t}")
     if m is None and t is None:
-        print(f"Not m,t  {m}, {t}")
+        logging.info(f"Not m,t  {m}, {t}")
         return context, None
 
     if m and m.process_name in {Names.EXECUTE, Names.BIND, Names.SYNC, Names.DESCRIBE}:
         return context.update_mem('message', m), m.process_name
 
-    print(f"Expected an extended protocol query message but got {m}, {t}")
+    logging.info(f"Expected an extended protocol query message but got {m}, {t}")
     return context, Names.ERROR
 
 
@@ -208,6 +214,7 @@ def write_data_frame_response(context: Context):
 
     DataFrameRowDescription(df=df).write(context.output)
     rows = DataFrameDataRows(df=df, offset=0, max_rows=1000000).write(context.output)
+
     CommandComplete(tag=f"SELECT {rows}").write(context.output)
 
     context.output.flush()
