@@ -1,4 +1,5 @@
 import io
+import logging
 from dataclasses import dataclass
 from typing import Any, List
 
@@ -9,6 +10,24 @@ from pypsql_api.wire.bytes import WritingIO
 from pypsql_api.wire.dataframe.types import TYPE_MAP, DataType
 
 
+@dataclass
+class ParameterStatus:
+    name: str
+    value: str
+
+    def write(self, buff: WritingIO):
+        buff.write_byte(ord('S'))
+        internal_buff = WritingIO(io.BytesIO())
+
+        internal_buff.write_cstring(self.name)
+        internal_buff.write_cstring(self.value)
+
+        bytes = internal_buff.buff.getvalue()
+
+        buff.write_int32(len(bytes) + 4)
+        buff.write_bytes(bytes)
+
+
 @dataclass
 class ErrorField:
     type: int  # one of https://www.postgresql.org/docs/current/protocol-error-fields.html
@@ -28,7 +47,7 @@ class ErrorResponse:
 
         bytes = internal_buff.buff.getvalue()
 
-        buff.write_int32(len(bytes) + 4)
+        buff.write_int32(len(bytes) + 5)
         buff.write_bytes(bytes)
 
         buff.write_byte(0)
@@ -125,7 +144,7 @@ class CommandComplete:
 
         buff.write_int32(len(bytes) + 4)  # Length of message contents in bytes, including self.
         buff.write_bytes(bytes)
-        print("writing COMMAND COMPLETE")
+        logging.info("writing COMMAND COMPLETE")
 
 
 def is_nan(x):
@@ -173,18 +192,19 @@ class DataFrameDataRows:
                 internal_buff.write_int16(len(column_types))
 
                 for i, type_map in enumerate(column_types):
-                    self.write_cell(internal_buff, row_i+offset, column_names[i], type_map, df)
+                    self.write_cell(internal_buff, row_i + offset, column_names[i], type_map, df)
 
                 data_row_bts = internal_buff.buff.getvalue()
 
                 buff.write_int32(len(data_row_bts) + 4)  # Length of message contents in bytes, including self.
                 buff.write_bytes(data_row_bts)
 
-            print(f"done writing datarows {row_count}")
+            logging.info(f"done writing datarows {row_count}")
             return row_count
 
         return 0
 
+
 @dataclass
 class DataFrameRowDescription:
     df: DataFrame
